{% extends "layout.html" %}
{% block title %}
{{ hilite.title() }} -
{% endblock %}
{% block content %}
<div class="entry-content">
    {% for c in preview_posts %}
    <div class="content-title">
        <small>{{ c.meta.title.upper() }}</small>
    </div>
    <div class="content-preview">
        {{ c.content }}
    </div>
    {% endfor %}

</div>
<header class="entry-header">
    <h3 class="entry-title">Articles {% if hilite != 'home' %} in {{ hilite.title() }} {% endif %}</h3>
</header>
<ul class="entry-list">
    {% for p in public_posts %}
    {% if not p.meta.preview %}
    <li>
    <h4>
        <a href="/{{ p.meta.link }}">{{ p.meta.title.title() }}</a>
        <small>
            Published on
            <time class="publish-date" datetime="{{ p.meta.date }}">{{ p.meta.date }}</time>
            by
            <span class="author-name">{{ site.author }}</span>
        </small>
    </h4>
    </li>
    {% endif %}
    {% endfor %}
</ul>
{% endblock %}
