<!DOCTYPE HTML>
<html lang="en">
    <head>
        <meta charset="UTF-8">
        <title>{% block title %}{% endblock %} {{ site.site_name }}</title>
        <meta name="viewport" content="width=device-width, initial-scale=1,maximum-scale=1">
        <link media="all" rel="stylesheet" href="/static/{{ context.theme }}/css/reset.css" type="text/css" />
        <link media="all" rel="stylesheet" href="/static/{{ context.theme }}/css/typo.css" type="text/css" />
        <link media="all" rel="stylesheet" href="/static/{{ context.theme }}/css/style.css" type="text/css" />
    </head>
    <body>
        <header id="header">
            <h1 class="brand"><a href="/">{{ site.site_name }}</a></h1>
            <nav id="nav">
                <ul class="fn-clear">
                    <li class="fn-left">
                    <a class="nav-home" href="/">Home</a>
                    </li>
                    {% for n in context.folder if n %}
                    <li class="fn-left">
                    <a class="nav-{{ n }}" href="/{{ n }}">{{ n.title() }}</a>
                    </li>
                    {% endfor %}
                    <li class="fn-left">
                    <a href="/feed.xml">Feed</a>
                    </li>
                </ul>
            </nav>
        </header>
        <div class="wrap typo">
            {% block content %}{% endblock %}
            <div class="end">&#10084;</div>
        </div>
        <footer id="footer">
            <small>Copyright by <a class="copyright" href="{{ site.site_url }}">{{ site.site_name.upper() }}</a> | Powered by <a href="https://github.com/ibigbug/sblog">SBlog</a></small>
        </footer>
        {% if context.ga %}
        <script type="text/javascript">
            var _gaq = _gaq || [];
            _gaq.push(['_setAccount', '{{ context.ga }}']);
            _gaq.push(['_trackPageview']);
            (function() {
                var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
                ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
                var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
            })();
        </script>
        {% endif %}
        <link href='http://fonts.googleapis.com/css?family=Strait&subset=latin,cyrillic' rel='stylesheet' type='text/css'>

    </body>
</html>
