body { 
    text-align: center;
    font-family: 'Strait', sans-serif;
}
#header {
    position: fixed;
    top: 0;
    width: 100%;
    height: 50px;
    line-height: 50px;
    box-shadow: 0 1px 1px #ddd;
    background-color: #f5f5f5;
    z-index: 9;
}
.brand {
    float: left;
}
.brand a {
    color: #dcdcdc;
    border: none;
}
.brand a:hover {
    color: #ccc;
}
#nav {
    margin: 0 auto;
    max-width: 600px;
    text-align: left;
    font-size: 16px;
}

#nav li {
    margin-right: 20px;
}
#nav a {
    border: none;
    font-weight: bold;
    padding-bottom: 5px;
}
#nav a:hover {
    border-bottom: 3px solid #dc143c;
}

.wrap {
    max-width: 600px;
    margin: 0 auto;
    text-align: left;
    margin-top: 120px;
}
.entry-content {
    margin-bottom: 40px;
}
.entry-content .content-title small {
    color: #ddd;
}
.entry-content .content-preview {
    margin-top: 20px;
}
.entry-list li {
    list-style-type: none;
}
.entry-list li h3 {
    margin-right: 8px;
}
.entry-meta {
    display: block;
    margin-bottom: 10px;
}
.end {
    text-align: center;
    color: #aaa;
    margin-top: 50px;
    font-size: 40px;
}

#footer {
    max-width: 600px;
    text-align: center;
    margin: 0 auto;
}
a:hover {
    -webkit-transition: color 0.5s ease;
    -moz-transition: color 0.5s ease;
    transition: color 0.5s ease;
}
